@@ -32,10 +32,9 @@ from dimp import *
 
 from .plugins import *
 
-from .network import CASubject, CAValidity, CAData, CertificateAuthority
 from .network import ServiceProvider, Station, Robot
 
-from .group import Polylogue
+from .group import Polylogue, Chatroom, ChatroomDataSource
 
 from .protocol import ReceiptCommand, HandshakeCommand, LoginCommand
 from .protocol import BlockCommand, MuteCommand, StorageCommand
@@ -44,11 +43,14 @@ from .cpu import ContentProcessor, ForwardContentProcessor, FileContentProcessor
 from .cpu import CommandProcessor, HistoryCommandProcessor, GroupCommandProcessor
 from .cpu import InviteCommandProcessor, ExpelCommandProcessor, QuitCommandProcessor
 from .cpu import ResetCommandProcessor, QueryCommandProcessor
-from .cpu import MetaCommandProcessor, ProfileCommandProcessor
+from .cpu import MetaCommandProcessor, DocumentCommandProcessor
 
-from .delegate import Callback, CompletionHandler, MessengerDelegate
+from .delegate import Callback, CompletionHandler, MessengerDelegate, MessengerDataSource
 
 from .facebook import Facebook
+from .packer import MessagePacker
+from .processor import MessageProcessor
+from .transmitter import MessageTransmitter
 from .messenger import Messenger
 
 from .ans import AddressNameService
@@ -60,97 +62,37 @@ __author__ = 'Albert Moky'
 __all__ = [
 
     #
-    #   MingKeMing
+    #   Plugins
     #
-
-    # crypto
-    'SignKey', 'VerifyKey', 'EncryptKey', 'DecryptKey',
-    'SymmetricKey', 'PrivateKey', 'PublicKey',
-
-    # data
-    'BaseCoder',
-    'Base64', 'Base58', 'Hex',
-    'Digest',
-    'MD5', 'SHA1', 'SHA256', 'RIPEMD160',
-    'md5', 'sha1', 'sha256', 'ripemd160',
-
-    # entity
-    'NetworkID', 'MetaVersion',
-    'Address', 'ID', 'Meta', 'Profile',
-    'Entity', 'User', 'Group',
-
-    # delegate
-    'EntityDataSource', 'UserDataSource', 'GroupDataSource',
-
-    'ANYONE', 'EVERYONE', 'ANYWHERE', 'EVERYWHERE',
+    'PlainKey',
+    'BTCAddress', 'ETHAddress',
+    'DefaultMeta', 'BTCMeta', 'ETHMeta',
 
     #
-    #   DaoKeDao
+    #   Protocol
     #
-
-    'ContentType',
-    'Envelope',
-    'Message',
-
-    # transform
-    'InstantMessage', 'SecureMessage', 'ReliableMessage',
-
-    # delegate
-    'InstantMessageDelegate', 'SecureMessageDelegate', 'ReliableMessageDelegate',
-
-    #
-    #   DIMP
-    #
-
-    # protocol
-    'Content', 'ForwardContent', 'TextContent',
-    'FileContent', 'ImageContent', 'AudioContent', 'VideoContent',
-    'Command', 'HistoryCommand', 'GroupCommand',
-    'InviteCommand', 'ExpelCommand', 'JoinCommand', 'QuitCommand',
-    'QueryCommand', 'ResetCommand',
-    'MetaCommand', 'ProfileCommand',
-
-    # delegate
-    'EntityDelegate', 'CipherKeyDelegate',
-
-    # core
-    'Barrack', 'Transceiver',
-
-    #
-    #   DIM SDK
-    #
-
-    # network
-    'CASubject', 'CAValidity', 'CAData', 'CertificateAuthority',
-    'ServiceProvider', 'Station', 'Robot',
-
-    # group
-    'Polylogue',
-
-    # protocol
     'ReceiptCommand', 'HandshakeCommand', 'LoginCommand',
     'BlockCommand', 'MuteCommand', 'StorageCommand',
 
-    # cpu
+    #
+    #   Content/Command Processors
+    #
     'ContentProcessor', 'ForwardContentProcessor', 'FileContentProcessor',
-    'CommandProcessor', 'HistoryCommandProcessor', 'GroupCommandProcessor',
+    'CommandProcessor', 'HistoryCommandProcessor',
+    'GroupCommandProcessor',
     'InviteCommandProcessor', 'ExpelCommandProcessor', 'QuitCommandProcessor',
     'ResetCommandProcessor', 'QueryCommandProcessor',
-    'MetaCommandProcessor', 'ProfileCommandProcessor',
+    'MetaCommandProcessor', 'DocumentCommandProcessor',
+
+    # network
+    'ServiceProvider', 'Station', 'Robot',
+
+    # group
+    'Polylogue', 'Chatroom', 'ChatroomDataSource',
 
     # delegate
-    'Callback', 'CompletionHandler', 'MessengerDelegate',
+    'Callback', 'CompletionHandler', 'MessengerDelegate', 'MessengerDataSource',
 
-    'Facebook', 'Messenger',
-    'AddressNameService',
-
-    #
-    #  Sub Modules
-    #
-
-    #  1. dos
-    #  2. apns
-    #  3. notifications
-    #  4. plugins
-    #  5. immortals
+    'AddressNameService', 'Facebook',
+    'Messenger', 'MessagePacker', 'MessageProcessor', 'MessageTransmitter',
 ]
