@@ -38,23 +38,42 @@
 
 from typing import Optional
 
-from dimp import ID
 from dimp import ReliableMessage
 from dimp import Content
-from dimp import GroupCommand, ExpelCommand
+from dimp import Command, ExpelCommand
 
 from .history import GroupCommandProcessor
 
 
 class ExpelCommandProcessor(GroupCommandProcessor):
 
-    def __remove(self, expel_list: list, group: ID) -> Optional[list]:
+    def execute(self, cmd: Command, msg: ReliableMessage) -> Optional[Content]:
+        assert isinstance(cmd, ExpelCommand), 'group command error: %s' % cmd
         facebook = self.facebook
-        # existed members
-        members: list = facebook.members(identifier=group)
-        if members is None:
-            members = []
-        # removed member(s)
+        from ..facebook import Facebook
+        assert isinstance(facebook, Facebook), 'entity delegate error: %s' % facebook
+        # 0. check group
+        group = cmd.group
+        owner = facebook.owner(identifier=group)
+        members = facebook.members(identifier=group)
+        if owner is None or members is None or len(members) == 0:
+            raise LookupError('Group not ready: %s' % group)
+        # 1. check permission
+        sender = msg.sender
+        if sender != owner:
+            # not the owner? check assistants
+            assistants = facebook.assistants(identifier=group)
+            if assistants is None or sender not in assistants:
+                text = '%s is not the owner/assistant of group %s, cannot expel member' % (sender, group)
+                raise AssertionError(text)
+        # 2. expelling members
+        expel_list = self.members(cmd=cmd)
+        if expel_list is None or len(expel_list) == 0:
+            raise ValueError('expel command error: %s' % cmd)
+        # 2.1. check owner
+        if owner in expel_list:
+            raise AssertionError('cannot expel owner %s of group %s' % (owner, group))
+        # 2.2. build removed-list
         remove_list = []
         for item in expel_list:
             if item not in members:
@@ -62,33 +81,9 @@ class ExpelCommandProcessor(GroupCommandProcessor):
             # expelled member found
             remove_list.append(item)
             members.remove(item)
-        # response removed-list after changed
+        # 2.3. do expel
         if len(remove_list) > 0:
             if facebook.save_members(members=members, identifier=group):
-                return remove_list
-
-    #
-    #   main
-    #
-    def process(self, content: Content, sender: ID, msg: ReliableMessage) -> Optional[Content]:
-        assert isinstance(content, ExpelCommand), 'group command error: %s' % content
-        facebook = self.facebook
-        group: ID = content.group
-        # 1. check permission
-        if not facebook.is_owner(member=sender, group=group):
-            if not facebook.exists_assistant(member=sender, group=group):
-                raise AssertionError('only owner/assistant can expel: %s' % msg)
-        # 2.1. get expelling members
-        expel_list: list = self.members(content=content)
-        if expel_list is None or len(expel_list) == 0:
-            raise ValueError('expel command error: %s' % content)
-        # 2.2. get removed-list
-        remove_list = self.__remove(expel_list=expel_list, group=group)
-        if remove_list is not None:
-            content['removed'] = remove_list
+                cmd['removed'] = remove_list
         # 3. response (no need to response this group command)
         return None
-
-
-# register
-GroupCommandProcessor.register(command=GroupCommand.EXPEL, processor_class=ExpelCommandProcessor)
