@@ -35,7 +35,6 @@
     As receipt returned to sender to proofing the message's received
 """
 
-import time as time_lib
 from typing import Union, Optional
 
 from dimp import ID
@@ -71,46 +70,20 @@ class LoginCommand(Command):
         }
     """
 
-    def __new__(cls, cmd: dict):
-        """
-        Create login command
-
-        :param cmd: command info
-        :return: LoginCommand object
-        """
+    def __init__(self, cmd: Optional[dict]=None, identifier: Optional[ID]=None):
         if cmd is None:
-            return None
-        elif cls is LoginCommand:
-            if isinstance(cmd, LoginCommand):
-                # return LoginCommand object directly
-                return cmd
-        # new LoginCommand(dict)
-        return super().__new__(cls, cmd)
-
-    def __init__(self, content: dict):
-        if self is content:
-            # no need to init again
-            return
-        super().__init__(content)
-        # login time
-        self.__time: int = None
-
-    @property
-    def time(self) -> int:
-        if self.__time is None:
-            time = self.get('time')
-            if time is None:
-                self.__time = 0
-            else:
-                self.__time = int(time)
-        return self.__time
+            super().__init__(command=Command.LOGIN)
+        else:
+            super().__init__(cmd=cmd)
+        if identifier is not None:
+            self['ID'] = str(identifier)
 
     #
     #   Client Info
     #
     @property
-    def identifier(self) -> Union[ID, str]:
-        return self.get('ID')
+    def identifier(self) -> ID:
+        return ID.parse(identifier=self.get('ID'))
 
     # Device ID
     @property
@@ -152,7 +125,7 @@ class LoginCommand(Command):
         else:
             assert isinstance(value, Station), 'station error: %s' % value
             self['station'] = {
-                'ID': value.identifier,
+                'ID': str(value.identifier),
                 'host': value.host,
                 'port': value.port,
             }
@@ -170,37 +143,5 @@ class LoginCommand(Command):
         else:
             assert isinstance(value, ServiceProvider), 'SP error: %s' % value
             self['provider'] = {
-                'ID': value.identifier,
+                'ID': str(value.identifier),
             }
-
-    #
-    #   Factories
-    #
-    @classmethod
-    def new(cls, content: dict=None, identifier: ID=None, time: int=0):
-        """
-        Create login command for user
-
-        :param content:    command info
-        :param identifier: user ID
-        :param time:       command time
-        :return: LoginCommand object
-        """
-        if content is None:
-            # create empty content
-            content = {}
-        # set command name: 'meta'
-        if 'command' not in content:
-            content['command'] = Command.LOGIN
-        # set entity ID
-        if identifier is not None:
-            content['ID'] = identifier
-        # set current time
-        if 'time' not in content:
-            content['time'] = int(time_lib.time())
-        # new LoginCommand(dict)
-        return super().new(content=content, time=time)
-
-
-# register command class
-Command.register(command=Command.LOGIN, command_class=LoginCommand)
